@@ -1,7 +1,6 @@
 from pandas import DataFrame as df
 from pandas import Timestamp as ts
 from tabulate import tabulate
-
 from liualgotrader.common import config
 from liualgotrader.common.tlog import tlog
 
@@ -13,11 +12,9 @@ def add_daily_vwap(minute_data: df, debug=False) -> bool:
         back_time_index = minute_data["close"].index.get_loc(
             back_time, method="nearest"
         )
-    except IndexError as e:
+    except Exception as e:
         if debug:
-            tlog(
-                f"IndexError exception {e} in add_daily_vwap for {minute_data}"
-            )
+            tlog(f"IndexError exception {e} in add_daily_vwap for {minute_data}")
         return False
 
     minute_data["pv"] = minute_data.apply(
@@ -33,11 +30,7 @@ def add_daily_vwap(minute_data: df, debug=False) -> bool:
 
     # print(f"\n{tabulate(minute_data, headers='keys', tablefmt='psql')}")
     if debug:
-        tlog(
-            f"\n{tabulate(minute_data[-110:-100], headers='keys', tablefmt='psql')}"
-        )
-        tlog(
-            f"\n{tabulate(minute_data[-10:], headers='keys', tablefmt='psql')}"
-        )
+        tlog(f"\n{tabulate(minute_data[-110:-100], headers='keys', tablefmt='psql')}")
+        tlog(f"\n{tabulate(minute_data[-10:], headers='keys', tablefmt='psql')}")
 
     return True
